@@ -1,10 +1,12 @@
 import os
 from dotenv import load_dotenv
+system_name=os.getlogin()
+PATH=str(f'C:\\Users\\{system_name}\\AppData\\Roaming\\Python\\Python39\\site-packages\\command_line')
 try:
-    load_dotenv("config.env")
+    load_dotenv(f"{PATH}\\config.env")
 except Exception as e:
     print(e)
-files = os.listdir(os.getcwd())
+files = os.listdir(PATH)
 if "config.env" not in files:
     TOKEN_INSERTED = False
 else:
